<?php
/**
*
* @package phpBB Extension - Stoker Portal
* @copyright (c) 2015 Stoker www.phpbb3bbcodes.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\portal\controller;

/**
* @ignore
*/

class main
{
	/** @var \phpbb\cache\driver\driver_interface */
	protected $cache;
	
	/* @var \phpbb\config\config */
	protected $config;

	/* @var \phpbb\config\db_text */
	protected $config_text;

	/* @var \phpbb\controller\helper */
	protected $helper;

	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/* @var string phpEx */
	protected $php_ext;
	/**
	* Constructor
	*
	* @param \phpbb\config\config		$config
	* @param \phpbb\config\db_text		$config_text
	* @param \phpbb\controller\helper	$helper
	* @param \phpbb\template\template	$template
	* @param \phpbb\user				$user
	* @param string						$php_ext	phpEx
	*/
	public function __construct(\phpbb\cache\driver\driver_interface $cache, \phpbb\config\config $config, \phpbb\config\db_text $config_text, \phpbb\controller\helper $helper, \phpbb\template\template $template, \phpbb\user $user, $php_ext)
	{
		$this->cache = $cache;
		$this->config 	= $config;
		$this->helper 	= $helper;
		$this->template = $template;
		$this->user 	= $user;
		$this->php_ext 	= $php_ext;
		$this->config_text = $config_text;
	}

	/**
	* Controller for route app.php/portal.php and /portal
	*
	* @return Symfony\Component\HttpFoundation\Response A Symfony Response object
	*/
	public function base()
	{
		$date = $this->user->format_date(time(), 'H');

		if ($this->user->data['is_registered'])
		{
			$u_user_name = get_username_string('full', $this->user->data['user_id'], $this->user->data['username'], $this->user->data['user_colour']);
		}
		else
		{
			$u_user_name = $this->user->lang['WELCOME_GUEST'];
		}    

		switch (true)
		{
			case ($date < 1):
				// if the hour is 01 - 23
				$s_welcome = sprintf($this->user->lang['GOOD_NIGHT'], $u_user_name);;
			break;
			
			case ($date < 4):
				// if the hour is 01 - 04
				$s_welcome = sprintf($this->user->lang['UP_LATE'], $u_user_name);
			break;
			
			case ($date < 7):
				// if the hour is 04 - 07 
				$s_welcome = sprintf($this->user->lang['UP_EARLY'], $u_user_name);
			break;
			
			case ($date < 10):
				// if the hour is 07 - 10 am
				$s_welcome = sprintf($this->user->lang['GOOD_MORNING'], $u_user_name);
			break;
			
			case ($date < 14):
				// if the hour is 10 - 14
				$s_welcome = sprintf($this->user->lang['GOOD_DAY'], $u_user_name);
			break;
			
			case ($date < 18):
				// if the hour is 14 - 18
				$s_welcome = sprintf($this->user->lang['GOOD_AFTERNOON'], $u_user_name);
			break;
			
			case ($date < 24):
				// if the hour is 18 - 24
				$s_welcome = sprintf($this->user->lang['GOOD_EVENING'], $u_user_name);;
			break;
		}

		// how long a member for
		$member_for = '';
		if ($this->user->data['is_registered'] && !$this->user->data['is_bot'])
		{
			$member_length = time() - $this->user->data['user_regdate'];
			$years = $months = $days = 0;
			$member_for = '';
			if ($member_length)
			{    
				if ($member_length >= 31536000)
				{
					$years = floor($member_length / 31536000);
					$member_length = $member_length - ($years * 31536000);
					$member_for .= $years > 1 ? ($years . '&nbsp;' . $this->user->lang['WELCOME_YEARS'] . ', ') : ($years . '&nbsp;' . $this->user->lang['WELCOME_YEAR'] . ', ');
				}
				$months = floor($member_length / 2628000);
				if ($months)
				{
					$months = $months > 1 ? ($months . '&nbsp;' . $this->user->lang['WELCOME_MONTHS'] . ', ') : ($months . '&nbsp;' . $this->user->lang['WELCOME_MONTHS'] . ', ');
					$member_length = $member_length - ($months * 2628000);
					$member_for .= $months;
				}
				$days = floor($member_length / 86400);
				if ($days)
				{
					$days = $days > 1 ? ($days . '&nbsp;' . $this->user->lang['WELCOME_DAYS']) : ($days . '&nbsp;' . $this->user->lang['WELCOME_DAY']);
					$member_for .= $days;
				}        
			}
		}
		$portal_data = $this->cache->get('_simpleportal_data');
		$portal_data = $this->config_text->get_array(array(
				'portal_info',
				'portal_info_uid',
				'portal_info_bitfield',
				'portal_info_flags',
		));
		$this->cache->put('_simpleportal_data', $portal_data);

		$portal_text = generate_text_for_display(
			$portal_data['portal_info'],
			$portal_data['portal_info_uid'],
			$portal_data['portal_info_bitfield'],
			$portal_data['portal_info_flags']
		);

		$this->template->assign_vars(array(
			'S_WELCOME'             => $s_welcome,
			'S_JOINED_DATE'         => $this->user->lang['JOINED'] . ':&nbsp;' . $this->user->format_date($this->user->data['user_regdate']),
			'MEMBER_FOR'            => (!empty($member_for)) ? $this->user->lang['MEMBER_FORP'] . '&nbsp;' . $member_for : '',
			'PORTAL_OUTPUT'			=> $portal_text,
			'PORTAL_ENABLE'			=> $this->config['acp_portal_enable'],
			'S_IN_PORTAL'			=> true,
		));

		return $this->helper->render('portal_body.html', $this->user->lang('PORTAL'));
	}

	public function redirect()
	{
		redirect($this->helper->route('stoker_portal'));
	}

}