<?php
/**
*
* @package phpBB Extension - Stoker Portal
* @copyright (c) 2015 Stoker www.phpbb3bbcodes.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\portal\event;

/**
* @ignore
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class main_listener implements EventSubscriberInterface
{
	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'						=> 'load_language_on_setup',
			'core.page_header'						=> 'add_page_header_link',
			'core.viewonline_overwrite_location'	=> 'add_portal_viewonline',
		);
	}
	/** @var \phpbb\config\config */
	protected $config;

	/* @var \phpbb\controller\helper */
	protected $helper;

	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/* @var string phpEx */
	protected $php_ext;

	/**
	* Constructor
	*
	* @param \phpbb\controller\helper	$helper		Controller helper object
	* @param \phpbb\template			$template	Template object
	* @param string						$php_ext	phpEx
	*/
	public function __construct(\phpbb\config\config $config, \phpbb\controller\helper $helper, \phpbb\template\template $template, \phpbb\user $user, $php_ext, \phpbb\collapsiblecategories\operator\operator $operator = null)
	{
		$this->config = $config;
		$this->helper = $helper;
		$this->template = $template;
		$this->user = $user;
		$this->php_ext = $php_ext;
		$this->operator = $operator;
	}

	public function load_language_on_setup($event)
	{	
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'stoker/portal',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function add_page_header_link($event)
	{
		if ($this->operator !== null)
		{
			$fid = 'foo_portalwelcome'; // can be any unique string to identify your extension's collapsible element
			$this->template->assign_vars(array(
				'S_FOO_PORTALWELCOME_HIDDEN' => in_array($fid, $this->operator->get_user_categories()),
				'U_FOO_PORTALWELCOME_COLLAPSE_URL' => $this->helper->route('phpbb_collapsiblecategories_main_controller', array(
					'forum_id' => $fid,
					'hash' => generate_link_hash("collapsible_$fid")))
			));
		}
		
		$this->template->assign_vars(array(
			'U_PORTAL'			=> $this->helper->route('stoker_portal'),
			'PORTAL_ENABLE'		=> $this->config['acp_portal_enable'],
		));
	}

	public function add_portal_viewonline($event)
	{
		if ($event['row']['session_page'] === 'app.' . $this->php_ext . '/portal.php')
		{
				$event['location'] = $this->user->lang('VIEWONLINE_PORTAL');
				$event['location_url'] = $this->helper->route('stoker_portal');
		}
	}
}
